love.terminal = require("terminal")
love.profile = require("profile")

-- use Love's timer instead of os.clock
love.profile.setclock(love.timer.getTime)
-- hook only Lua functions
--love.profile.hookall("Lua")
-- start profiling
love.profile.start()

local frame = 0

function love.update(dt)
  love.terminal.clear()
  
  -- trace some basic stuff
	love.terminal.trace('delta', dt)
	love.terminal.trace('memory', collectgarbage('count'))
	love.terminal.trace('frame', frame)
  
  -- reset the profiler every 100 frames
  if frame%100 == 0 then
    love.terminal.printf("top 30 functions sorted by time per 100 frames")
    love.terminal.printf("==============================================")
    local n = 1
    -- query top 50 functions by time
    for f, c, t, d in love.profile.query("time", 30) do
      -- f = function, c = calls, t = time, d = line
      love.terminal.printf("%d.'%s'x%d time:%s (%s)", n, f, c, t, d)
      n = n + 1
    end
    love.profile.reset()
    -- the profiler is a beast in terms of memory
    collectgarbage("restart")
    collectgarbage("collect")
  end
    
  frame = frame + 1
end

function love.draw()
  love.graphics.setBackgroundColor(255, 0, 0)
  love.graphics.clear()
	love.terminal.redraw()
end